JwtClaims

Struct JwtClaims 

pub struct JwtClaims {
    pub len_bytes: Wire,
    pub json: Vec<Wire>,
    pub attributes: Vec<Attribute>,
}
Verifies that a JSON string contains specific attribute values.

This circuit validates that the JSON contains each specified attribute with exactly the expected string value.

This circuit makes some strong assumptions, in particular:

  1. The input is a valid JSON object. No effort is put into checking that or any other properties such as duplicate keys.
  2. No whitespace handling.
  3. The attributes of interest are strings only. Matching arrays or objects as values is not supported.

❗️ At this point, the circuit does not check that it did not get multiple attributes. For example, imagine there are two attributes “sub” and “nonce” where one is right next to the other. A prover can get away with providing the attribute “sub” but the end quote of the nonce.

Fields

len_bytes: Wire

The actual length of the JSON string in bytes.

json: Vec<Wire>attributes: Vec<Attribute>

Implementations

Source

impl JwtClaims

pub fn new( b: &CircuitBuilder, len_bytes: Wire, json: Vec<Wire>, attributes: Vec<Attribute>, ) -> Self

Creates a new JWT claims verifier circuit. See the struct documentation for more details.

Arguments
  • b - Circuit builder
  • len_bytes - Wire for actual JSON size in bytes
  • json - JSON input array packed as words (8 bytes per word)
  • attributes - List of attributes to verify with their value wires
pub fn populate_len_bytes(&self, w: &mut WitnessFiller<'_>, len_bytes: usize)

Populate the len_bytes wire with the actual JSON size in bytes

pub fn populate_json(&self, w: &mut WitnessFiller<'_>, json: &[u8])

Populate the JSON array from a byte slice

Panics

Panics if json.len() > max_len_json (the maximum size specified during construction)